@@ -12,7 +12,7 @@ import (
 	"github.com/spf13/pflag"
 	"k8s.io/klog"
 
-	"github.com/open-cluster-management/multicluster-observability-operator/loaders/dashboards/pkg/controller"
+	"github.com/stolostron/multicluster-observability-operator/loaders/dashboards/pkg/controller"
 )
 
 func main() {
